-- Land unit rebalances for 8 Ages of War
-- Author: Olleus
-- DateCreated: 8/9/2017 8:02:07 PM
--------------------------------------------------------------

-- Changes are done this way so that all UUs (future and present) that
-- replace a unit get the same changes done to them. However, if a patch
-- changes a unit strength, this mod will follow that change.

-- TO DO: Check Obsolete techs and upgrade paths all make sense

--------------------------------------------------------------
-- ANCIENT ERA
--------------------------------------------------------------

-- Warrior, Scout, and Slinger unchanged
-- Eagle Warrior, Warcart unchanged

UPDATE Units		--18/7
	SET RangedCombat = RangedCombat - 7, Combat = Combat - 8
	WHERE UnitType = "UNIT_ARCHER" -- Also Pitati Archer
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_ARCHER");

UPDATE Units		-- 28
	SET Combat = Combat + 3
	WHERE UnitType = "UNIT_SPEARMAN" -- Also Hoplite
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_SPEARMAN");

UPDATE Units		-- 30 (3+1)
	SET Combat = Combat + 2, BaseMoves = BaseMoves + 1
	WHERE UnitType = "UNIT_HEAVY_CHARIOT"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_HEAVY_CHARIOT");

-- Deal with Maryannu egyptian chariot separately because so different to parent unit
UPDATE Units		-- 22/16 (r2 m3+1)
	SET RangedCombat = 22, Combat = 16
	WHERE UnitType = "UNIT_EGYPTIAN_CHARIOT_ARCHER";

--------------------------------------------------------------
-- CLASSICAL ERA
--------------------------------------------------------------

UPDATE Units		-- 34
	SET Combat = Combat - 2
	WHERE UnitType = "UNIT_HORSEMAN" -- Also Hetairoi
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_HORSEMAN");

-- Swordsman (and Hypaspist, Legion, Ngao Mbeba ) unchanged (!)
-- Varu is Basically a swordsman, left unchanged (cost changed though)

UPDATE Units		-- 18/30
	SET RangedCombat = RangedCombat - 7
	WHERE UnitType = "UNIT_PERSIAN_IMMORTAL";

UPDATE Units		-- 20/12
	SET RangedCombat = RangedCombat - 5, Combat = Combat - 3
	WHERE UnitType = "UNIT_SCYTHIAN_HORSE_ARCHER";

UPDATE Units		-- 28/16
	SET Bombard = Bombard - 7, Combat = Combat - 7
	WHERE UnitType = "UNIT_CATAPULT"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_CATAPULT");

--------------------------------------------------------------
-- MEDIEVAL ERA
--------------------------------------------------------------

UPDATE Units		-- 44
	SET Combat = Combat + 3
	WHERE UnitType = "UNIT_PIKEMAN"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_PIKEMAN");

UPDATE UnitUpgrades
	SET UpgradeUnit = "UNIT_FUSILIER"
	WHERE Unit = "UNIT_PIKEMAN"
		OR Unit IN (SELECT CivUniqueUnitType FROM UnitReplaces
					WHERE ReplacesUnitType="UNIT_PIKEMAN");

UPDATE Units		-- 44
	SET Combat = Combat + 4
	WHERE UnitType = "UNIT_NORWEGIAN_BERSERKER";

UPDATE Units		-- 48
	SET Combat = Combat + 3
	WHERE UnitType = "UNIT_JAPANESE_SAMURAI";

UPDATE Units		-- 34/22
	SET RangedCombat = RangedCombat - 6, Combat = Combat - 6
	WHERE UnitType = "UNIT_CROSSBOWMAN"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_CROSSBOWMAN");

UPDATE Units		-- 42/26
	SET RangedCombat = RangedCombat - 8, Combat = Combat - 4
	WHERE UnitType = "UNIT_CHINESE_CROUCHING_TIGER";

UPDATE Units		-- 46
	SET Combat = Combat - 2
	WHERE UnitType = "UNIT_KNIGHT"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_KNIGHT");

UPDATE Units		-- 53
	SET Combat = Combat - 2
	WHERE UnitType = "UNIT_POLISH_HUSSAR";

--------------------------------------------------------------
-- RENAISSANCE ERA
--------------------------------------------------------------

UPDATE Units		-- 54
	SET Combat = Combat - 1
	WHERE UnitType = "UNIT_MUSKETMAN" -- Also Conquistador
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_MUSKETMAN");

UPDATE Units		-- 46/34
	SET Bombard = Bombard - 9, Combat = Combat - 9, PrereqTech = "TECH_SIEGE_TACTICS"
	WHERE UnitType = "UNIT_BOMBARD"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_BOMBARD");

UPDATE Units		-- 52 (4)
	SET Combat = Combat - 10, BaseMoves = BaseMoves - 1,
		PrereqTech = "TECH_METAL_CASTING", Maintenance = 4, Cost = Round(Cost * 0.848)
	WHERE UnitType = "UNIT_CAVALRY"  -- Also Cossack
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_CAVALRY");

--------------------------------------------------------------
-- INDUSTRIAL ERA
--------------------------------------------------------------

-- New Unit 'Fusilier' added separately [before this file is loaded] (anti cav, str 62)
DELETE 
	FROM TypeTags
	WHERE Tag = "CLASS_MELEE"
		AND (Type = "UNIT_ENGLISH_REDCOAT" OR Type = "UNIT_FRENCH_GARDE_IMPERIALE");

INSERT INTO TypeTags(Type, Tag)
	VALUES ("UNIT_ENGLISH_REDCOAT", "CLASS_ANTI_CAVALRY"),
		   ("UNIT_FRENCH_GARDE_IMPERIALE", "CLASS_ANTI_CAVALRY");

INSERT INTO UnitReplaces(CivUniqueUnitType, ReplacesUnitType)
	VALUES ("UNIT_ENGLISH_REDCOAT", "UNIT_FUSILIER"),
		   ("UNIT_FRENCH_GARDE_IMPERIALE", "UNIT_FUSILIER");

DELETE 
	FROM UnitUpgrades
	WHERE (Unit = "UNIT_ENGLISH_REDCOAT" OR Unit = "UNIT_FRENCH_GARDE_IMPERIALE");

INSERT INTO UnitUpgrades(Unit, UpgradeUnit)
	VALUES ("UNIT_ENGLISH_REDCOAT", "UNIT_AT_CREW"),
		   ("UNIT_FRENCH_GARDE_IMPERIALE", "UNIT_AT_CREW");

UPDATE Units		-- 66 for both
	SET Combat = Combat + 1, PromotionClass="PROMOTION_CLASS_ANTI_CAVALRY",
		Cost = 330, MandatoryObsoleteTech = "TECH_ROCKETRY"
	WHERE UnitType = "UNIT_ENGLISH_REDCOAT" OR UnitType = "UNIT_FRENCH_GARDE_IMPERIALE";

UPDATE Units		-- 62 (4)
	SET Combat = Combat - 5, BaseMoves = BaseMoves - 1
	WHERE UnitType = "UNIT_AMERICAN_ROUGH_RIDER";

UPDATE Units		-- 52/40
	SET RangedCombat = RangedCombat - 8, Combat = Combat - 10
	WHERE UnitType = "UNIT_FIELD_CANNON"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_FIELD_CANNON");

UPDATE Units		-- 52/45 (r1 m3)
	SET RangedCombat = RangedCombat - 5
	WHERE UnitType = "UNIT_RANGER"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_RANGER");

--------------------------------------------------------------
-- MODERN ERA
--------------------------------------------------------------

UPDATE Units		-- 72
	SET Combat = Combat + 2
	WHERE UnitType = "UNIT_INFANTRY"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_INFANTRY");

UPDATE Units		-- 68/52
	SET Bombard = Bombard - 12, Combat = Combat - 8
	WHERE UnitType = "UNIT_ARTILLERY"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_ARTILLERY");

UPDATE Units		-- 72
	SET Combat = Combat - 8
	WHERE UnitType = "UNIT_TANK"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_TANK");

--------------------------------------------------------------
-- ATOMIC ERA
--------------------------------------------------------------

UPDATE Units		-- 80		(Cost changes to reflect later era)
	SET Combat = Combat + 10, PrereqTech = "TECH_ROCKETRY",
		Cost = Cost * 1.4, Maintenance = Maintenance + 2
	WHERE UnitType = "UNIT_AT_CREW"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_AT_CREW");

UPDATE Units		-- 70/58 (r2)
	SET RangedCombat = RangedCombat - 5, Combat = Combat - 7, Range = Range + 1
	WHERE UnitType = "UNIT_MACHINE_GUN"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_MACHINE_GUN");

UPDATE Units		-- 80 (m5)
	SET Combat = Combat - 2, BaseMoves = BaseMoves + 1
	WHERE UnitType = "UNIT_HELICOPTER"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_HELICOPTER");
						
--------------------------------------------------------------
-- INFORMATION ERA
--------------------------------------------------------------

UPDATE Units		-- 90 (m3)
	SET Combat = Combat + 5
	WHERE UnitType = "UNIT_MECHANIZED_INFANTRY"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_MECHANIZED_INFANTRY");

UPDATE Units		-- 84/64 (r3)
	SET Bombard = Bombard - 11, Combat = Combat - 6
	WHERE UnitType = "UNIT_ROCKET_ARTILLERY"
		OR UnitType IN (SELECT CivUniqueUnitType FROM UnitReplaces
						WHERE ReplacesUnitType="UNIT_ROCKET_ARTILLERY");

-- Modern Armor is unchanged (!)

DELETE
	FROM Units
	WHERE UnitType = "UNIT_MODERN_AT";



--------------------------------------------------------------
-- GENEARL CHANGES 
--------------------------------------------------------------

-- Increase bonus anti-cav have against cav
UPDATE ModifierArguments
	SET Value = 15
	WHERE ModifierId = "ANTI_CAVALRY_COMBAT_BONUS";

UPDATE ModifierArguments
	SET Value = 12
	WHERE ModifierId = "ANTI_SPEAR";

-- All cavalry units are far more expensive
UPDATE Units
	SET Maintenance = Maintenance * 2, Cost = Round(Cost * 1.25)
	WHERE (PromotionClass = "PROMOTION_CLASS_HEAVY_CAVALRY" OR
		   PromotionClass = "PROMOTION_CLASS_LIGHT_CAVALRY");

-- All anti-cav units are cheaper
UPDATE Units
	SET Cost = Round(Cost * 0.75)
	WHERE PromotionClass = "PROMOTION_CLASS_ANTI_CAVALRY";

-- Let military engineer act as battering ram
INSERT INTO TypeTags(Type, Tag)
	VALUES ("UNIT_MILITARY_ENGINEER", "CLASS_BATTERING_RAM");

-- Gives Military Engineers 4 rather than two charges (now actually useful), make ram/tower upgrade to it
UPDATE Units
	SET buildcharges = 4
	WHERE UnitType = "UNIT_MILITARY_ENGINEER";

UPDATE UnitUpgrades
	SET UpgradeUnit = "UNIT_MILITARY_ENGINEER"
	WHERE Unit = "UNIT_BATTERING_RAM" OR Unit = "UNIT_SIEGE_TOWER";